"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.jobs_api import JobsApi  # noqa: E501


class TestJobsApi(unittest.TestCase):
    """JobsApi unit test stubs"""

    def setUp(self):
        self.api = JobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_jobs_id(self):
        """Test case for delete_jobs_id

        Removes the job by given id  # noqa: E501
        """
        pass

    def test_get_jobs(self):
        """Test case for get_jobs

        Retrieves list of Jobs  # noqa: E501
        """
        pass

    def test_get_jobs_id(self):
        """Test case for get_jobs_id

        Retrieve Job with the given ID  # noqa: E501
        """
        pass

    def test_patch_jobs_id(self):
        """Test case for patch_jobs_id

        Updates fields provided for Jobs with the ID given  # noqa: E501
        """
        pass

    def test_post_jobs(self):
        """Test case for post_jobs

        Creates a new Job  # noqa: E501
        """
        pass

    def test_put_jobs_id(self):
        """Test case for put_jobs_id

        Updates Job with the ID given  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
