"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.attribute_assignments_api import AttributeAssignmentsApi  # noqa: E501


class TestAttributeAssignmentsApi(unittest.TestCase):
    """AttributeAssignmentsApi unit test stubs"""

    def setUp(self):
        self.api = AttributeAssignmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_attribute_assignments_id(self):
        """Test case for delete_attribute_assignments_id

        Remove Attribute Assignment with given ID  # noqa: E501
        """
        pass

    def test_get_attribute_assignments(self):
        """Test case for get_attribute_assignments

        Retrieve a list of Attribute Assignments  # noqa: E501
        """
        pass

    def test_get_attribute_assignments_id(self):
        """Test case for get_attribute_assignments_id

        Retrieve Attribute Assignment with the given ID  # noqa: E501
        """
        pass

    def test_patch_attribute_assignments_id(self):
        """Test case for patch_attribute_assignments_id

        Update provided fields of Attribute Assignment by given ID  # noqa: E501
        """
        pass

    def test_post_attribute_assignments(self):
        """Test case for post_attribute_assignments

        Create a new Attribute Assignment  # noqa: E501
        """
        pass

    def test_put_attribute_assignments_id(self):
        """Test case for put_attribute_assignments_id

        Update an Attribute Assignment by given ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
