# flake8: noqa

"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "0.30.0"

# import ApiClient
from kdp_api.api_client import ApiClient

# import Configuration
from kdp_api.configuration import Configuration

# import exceptions
from kdp_api.exceptions import OpenApiException
from kdp_api.exceptions import ApiAttributeError
from kdp_api.exceptions import ApiTypeError
from kdp_api.exceptions import ApiValueError
from kdp_api.exceptions import ApiKeyError
from kdp_api.exceptions import ApiException
