"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.workspace_invitations_api import WorkspaceInvitationsApi  # noqa: E501


class TestWorkspaceInvitationsApi(unittest.TestCase):
    """WorkspaceInvitationsApi unit test stubs"""

    def setUp(self):
        self.api = WorkspaceInvitationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_workspace_invitations(self):
        """Test case for get_workspace_invitations

        Retrieves a list of workspace invitations  # noqa: E501
        """
        pass

    def test_get_workspace_invitations_id(self):
        """Test case for get_workspace_invitations_id

        Retrieves Workspace Invitation with given ID  # noqa: E501
        """
        pass

    def test_post_workspace_invitations(self):
        """Test case for post_workspace_invitations

        Creates a new workspace invitation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
