"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.applications_api import ApplicationsApi  # noqa: E501


class TestApplicationsApi(unittest.TestCase):
    """ApplicationsApi unit test stubs"""

    def setUp(self):
        self.api = ApplicationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_applications_id(self):
        """Test case for delete_applications_id

        Removes Application with the given ID  # noqa: E501
        """
        pass

    def test_get_applications(self):
        """Test case for get_applications

        Retrieves a list of Applications  # noqa: E501
        """
        pass

    def test_get_applications_id(self):
        """Test case for get_applications_id

        Retrieves Application with the given ID  # noqa: E501
        """
        pass

    def test_patch_applications_id(self):
        """Test case for patch_applications_id

        Updates provided fields of Application with the given ID  # noqa: E501
        """
        pass

    def test_post_applications(self):
        """Test case for post_applications

        Create a new Application  # noqa: E501
        """
        pass

    def test_put_applications_id(self):
        """Test case for put_applications_id

        Updates Application with the given ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
