"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.group_memberships_api import GroupMembershipsApi  # noqa: E501


class TestGroupMembershipsApi(unittest.TestCase):
    """GroupMembershipsApi unit test stubs"""

    def setUp(self):
        self.api = GroupMembershipsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_group_memberships_id(self):
        """Test case for delete_group_memberships_id

        Deletes the group membership with the given ID  # noqa: E501
        """
        pass

    def test_get_group_memberships(self):
        """Test case for get_group_memberships

        Retrieves a list of group memberships  # noqa: E501
        """
        pass

    def test_get_group_memberships_id(self):
        """Test case for get_group_memberships_id

        Retrieves a group membership with the given id  # noqa: E501
        """
        pass

    def test_patch_group_memberships_id(self):
        """Test case for patch_group_memberships_id

        Updates the provided properties of group membership with the given ID  # noqa: E501
        """
        pass

    def test_post_group_memberships(self):
        """Test case for post_group_memberships

        Create a new group membership  # noqa: E501
        """
        pass

    def test_put_group_memberships_id(self):
        """Test case for put_group_memberships_id

        Updates the group membership with the given ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
