"""
    Koverse Data Platform (KDP) API

    The KDP API is a REST API that can be used to create, access, and update data in KDP Workspaces  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import kdp_api
from kdp_api.api.workspaces_api import WorkspacesApi  # noqa: E501


class TestWorkspacesApi(unittest.TestCase):
    """WorkspacesApi unit test stubs"""

    def setUp(self):
        self.api = WorkspacesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_workspaces_id(self):
        """Test case for delete_workspaces_id

        Deletes Workspace with the ID given  # noqa: E501
        """
        pass

    def test_get_workspaces(self):
        """Test case for get_workspaces

        Retrieves a list of workspaces  # noqa: E501
        """
        pass

    def test_get_workspaces_id(self):
        """Test case for get_workspaces_id

        Retrieves Workspace with given ID  # noqa: E501
        """
        pass

    def test_patch_workspaces_id(self):
        """Test case for patch_workspaces_id

        Updates provided fields of Workspace with the ID given  # noqa: E501
        """
        pass

    def test_post_workspaces(self):
        """Test case for post_workspaces

        Creates a new Workspace  # noqa: E501
        """
        pass

    def test_put_workspaces_id(self):
        """Test case for put_workspaces_id

        Updates Workspace with the ID given  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
